opyenxes.extension package
==========================

Submodules
----------

opyenxes.extension.XExtension module
------------------------------------

.. automodule:: opyenxes.extension.XExtension
    :members:
    :undoc-members:
    :show-inheritance:

opyenxes.extension.XExtensionManager module
-------------------------------------------

.. automodule:: opyenxes.extension.XExtensionManager
    :members:
    :undoc-members:
    :show-inheritance:

opyenxes.extension.XExtensionParser module
------------------------------------------

.. automodule:: opyenxes.extension.XExtensionParser
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: opyenxes.extension
    :members:
    :undoc-members:
    :show-inheritance:
